# `BioClients.amp_t2d`

AMP T2D: Accelerating Medicines Partnership Type-2 Diabetes project.

* <https://www.nih.gov/research-training/accelerating-medicines-partnership-amp>
* <http://www.type2diabetesgenetics.org/>

## Usage

```
$ python3 -m BioClients.amp_t2d.Client -h
```
